/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2012 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 5.7                   *
*********************************************************************************
* Id: playerdialog.cpp,                           2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include "config.h"

#include <xincs.h>
#include <fx.h>

#include "icons.h"
#include "PlayerDialog.h"

// Message Map for the Scribble Window class
FXDEFMAP(PlayerDialog) PlayerDialogMap[]={

  //________Message_Type_____________________ID____________Message_Handler_______
  FXMAPFUNC(SEL_COMMAND,	   PlayerDialog::ID_ACCEPT,  PlayerDialog::onCmdAccept),
  FXMAPFUNC(SEL_COMMAND,	   PlayerDialog::ID_CANCEL,  PlayerDialog::onCmdCancel),
  FXMAPFUNCS(SEL_COMMAND,	   PlayerDialog::ID_FILTER_0,PlayerDialog::ID_FILTER_6,  PlayerDialog::onCmdFilter),
  FXMAPFUNCS(SEL_UPDATE,	   PlayerDialog::ID_FILTER_0,PlayerDialog::ID_FILTER_6,  PlayerDialog::onUpdFilter),
  };


FXIMPLEMENT(PlayerDialog,FXDialogBox,PlayerDialogMap,ARRAYNUMBER(PlayerDialogMap))

// the internal SDL player
#ifdef HAVE_SDL_SDL_H
extern "C" int loadPlayerFile(char[1024], int64_t, int64_t, int, int, int, int, int, int, int, float, char[1024]);
#endif

char plist[1024];
char filter[1024];
int px, py, pl, pf, pd, pa, pv;
int64_t pts, ptd;
float pta;
int i_filter = 0;

// Create properties dialog
PlayerDialog::PlayerDialog(FXWindow *own):FXDialogBox(own,"Start Player",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 4,4,4,4, 4,4){

  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);

  // buttons
  buttonsframe = new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0, 0,0,0,0);
  new FXButton(buttonsframe,tr("&CANC"),cancelicon,this,ID_CANCEL,BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y,0,0,0,0,8,8);
  new FXButton(buttonsframe,tr("&PLAY"),accepticon,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y);

  filtermenu = new FXMenuPane(this);
  filterbutton = new FXMenuButton(buttonsframe,"FILTER",NULL,filtermenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
  filterbutton->showMenu(FALSE);
#endif
  menu_filter_0 = new FXMenuRadio(filtermenu,"NULL",this,ID_FILTER_0);
  menu_filter_1 = new FXMenuRadio(filtermenu,"FLIP HOR",this,ID_FILTER_1);
  menu_filter_2 = new FXMenuRadio(filtermenu,"FLIP VERT",this,ID_FILTER_2); 
  menu_filter_1 = new FXMenuRadio(filtermenu,"DEINTERLACE",this,ID_FILTER_3);
  menu_filter_2 = new FXMenuRadio(filtermenu,"T.INTERLACE",this,ID_FILTER_4); 
  menu_filter_3 = new FXMenuRadio(filtermenu,"HQ DENOISE ",this,ID_FILTER_5); 
  menu_filter_4 = new FXMenuRadio(filtermenu,"SWAP U V",this,ID_FILTER_6); 

  }


void PlayerDialog::setCmd(char list[1024], int64_t ts, int64_t td, int x, int y, int l, int f, int d, int a, int v, float ta){ 
  px = x;
  py = y;
  pts = ts;
  ptd = td;
  pl = l;
  pf = f;
  pd = d;
  pa = a;
  pv = v;
  pta = ta;
  stpncpy(plist, list, sizeof(plist));

}

// Close dialog with an accept filter
long PlayerDialog::onCmdFilter(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_filter=FXSELID(sel)-ID_FILTER_1+1;
  if(0<=n_filter && n_filter<7){
    switch(FXSELID(sel)){
	  case ID_FILTER_0:
        stpncpy(filter, "null", sizeof(filter));
		i_filter = 0;
		break;
	  case ID_FILTER_1:
        stpncpy(filter, "hflip", sizeof(filter));
		i_filter = 1;
		break;
	  case ID_FILTER_2:
        stpncpy(filter, "vflip", sizeof(filter));
		i_filter = 2;
		break;
	  case ID_FILTER_3:
        stpncpy(filter, "yadif", sizeof(filter));
		i_filter = 3;
		break;
	  case ID_FILTER_4:
        stpncpy(filter, "tinterlace", sizeof(filter));
		i_filter = 4;
		break;
	  case ID_FILTER_5:
        stpncpy(filter, "hqdn3d", sizeof(filter));
		i_filter = 5;
		break;
	  case ID_FILTER_6:
        stpncpy(filter, "swapuv", sizeof(filter));
		i_filter = 6;
		break;
    }
  }

  getApp()->stopModal(this,true);
  PlayerDialog::hide();
  loadPlayerFile(plist, pts, ptd, px, py, pl, pf, pd, pa, pv, pta, filter); 

  return 1;
  }


long PlayerDialog::onUpdFilter(FXObject* sender,FXSelector sel,void*){
  FXint n_filter=FXSELID(sel)-ID_FILTER_1+1;
  sender->handle(this,i_filter==n_filter?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);

  return 1;
  }

// Close dialog with an accept
long PlayerDialog::onCmdAccept(FXObject*,FXSelector,void*){
  stpncpy(filter, "null", sizeof(filter));
  i_filter = 0;
  getApp()->stopModal(this,true);
  PlayerDialog::hide();
  loadPlayerFile(plist, pts, ptd, px, py, pl, pf, pd, pa, pv, pta, filter); 

  return 1;
  }

// Close dialog with a cancel
long PlayerDialog::onCmdCancel(FXObject*,FXSelector,void*){
  getApp()->stopModal(this,false);
  PlayerDialog::hide();

  return 1;
  }


// Destroy
PlayerDialog::~PlayerDialog(){

  delete cancelicon;
  delete accepticon;
#ifdef HAVE_LIBAVFILTER
  avfilter_uninit();
#endif
  }



